# django-enhanced-settings
![Tests](https://github.com/OrangutanGaming/django-enhanced-settings/workflows/Tests/badge.svg)
[![codecov](https://codecov.io/gh/OrangutanGaming/django-enhanced-settings/branch/master/graph/badge.svg)](https://codecov.io/gh/OrangutanGaming/django-enhanced-settings)
[![PyPI](https://img.shields.io/pypi/v/django-enhanced-settings)](https://pypi.org/project/django-enhanced-settings/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/django-enhanced-settings)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/django-enhanced-settings)

Allow for more complex and dynamic settings for Django
